Description Usage Arguments Details Value Examples
View source: R/monty-hall-problem.R
play_n_games() plays the Monty Hall Problem game a
assigned amount of times.
1 | play_n_games(n = 100)
|
n |
= The number of times the Monty Hall game will be run. |
The game replicates the game on the TV show "Let's Make a Deal" where there are three doors for a contestant to choose from, one of which has a car behind it and two have goats. The contestant selects a door, then the host opens a door to reveal a goat, and then the contestant is given an opportunity to stay with their original selection or switch to the other unopened door. There was a famous debate about whether it was optimal to stay or switch when given the option to switch, so this simulation was created to test both strategies.
The function returns a data frame with the results of the Monty Hall game simulations. The rows contain the game strategy information. The columns contain the game outcome information.
1 | play_n_games( n=100 )
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.